@@ -1887,7 +1887,7 @@ account_prepare_cb (GObject *source_object,
   TpAccount *account = TP_ACCOUNT (source_object);
   GError *error = NULL;
 
-  if (!tp_account_prepare_finish (account, result, &error))
+  if (!tp_proxy_prepare_finish (account, result, &error))
     {
       DEBUG ("Failed to prepare account: %s", error->message);
       g_error_free (error);
@@ -1903,7 +1903,7 @@ accounts_dialog_account_validity_changed_cb (TpAccountManager *manager,
     gboolean valid,
     EmpathyAccountsDialog *dialog)
 {
-  tp_account_prepare_async (account, NULL, account_prepare_cb, dialog);
+  tp_proxy_prepare_async (account, NULL, account_prepare_cb, dialog);
 }
 
 static void
@@ -2118,7 +2118,7 @@ accounts_dialog_manager_ready_cb (GObject *source_object,
   TpAccountManager *manager = TP_ACCOUNT_MANAGER (source_object);
   GError *error = NULL;
 
-  if (!tp_account_manager_prepare_finish (manager, result, &error))
+  if (!tp_proxy_prepare_finish (manager, result, &error))
     {
       DEBUG ("Failed to prepare account manager: %s", error->message);
       g_error_free (error);
@@ -2444,7 +2444,7 @@ do_constructed (GObject *object)
   /* Set up signalling */
   priv->account_manager = tp_account_manager_dup ();
 
-  tp_account_manager_prepare_async (priv->account_manager, NULL,
+  tp_proxy_prepare_async (priv->account_manager, NULL,
       accounts_dialog_manager_ready_cb, dialog);
 
   priv->connectivity = empathy_connectivity_dup_singleton ();
